@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 25 Mar 2012                                              }
+{ last modified: 11 Apr 2012                                              }
 {*************************************************************************/
 
 #include "mainwindow.h"
@@ -224,7 +224,10 @@ void MainWindow::changeSkin(const QString &skinName)
 
     btnPrev->setIcon(skin->icoPrev);
     btnStop->setIcon(skin->icoStop);
-    btnPlay->setIcon(skin->icoPlay);
+    if(player->getState() != pp_state_Playing)
+        btnPlay->setIcon(skin->icoPlay);
+    else
+        btnPlay->setIcon(skin->icoPause);
     btnNext->setIcon(skin->icoNext);
     btnParent->setIcon(skin->icoParent);
 
@@ -761,7 +764,7 @@ void MainWindow::onMenuEqualizerClick()
 {
     if(!player->getEqualizer()->getEffect())
     {
-        showNotification(tr("Equalizer module not found!") + " (" + player->getEqualizer()->getModuleName() +")");
+        showNotification(tr("Equalizer module not found!") + " (" + player->getEqualizer()->getModuleName() + ")");
         return;
     }
 
